@@ -17,7 +17,6 @@ class DocstringModifier(Plugin):
     """
 
     name = 'docstring-modifier'
-    args = dict()
 
     def describeTest(self, running_test):
 
@@ -26,8 +25,11 @@ class DocstringModifier(Plugin):
         if not test:
             return
 
-        prefix = self._get_affix('prefix', test)
-        suffix = self._get_affix('suffix', test)
+        prefix_list = self.conf.options.prefix
+        suffix_list = self.conf.options.suffix
+
+        prefix = self._get_affix(prefix_list, test)
+        suffix = self._get_affix(suffix_list, test)
 
         docstring = self._get_docstring(test)
 
@@ -50,44 +52,34 @@ class DocstringModifier(Plugin):
                  '--replace=a,A'
         )
 
-    def configure(self, options, conf):
-        super(DocstringModifier, self).configure(options, conf)
-
-        if options.prefix:
-            self.args['prefix'] = options.prefix.split(',')
-        if options.suffix:
-            self.args['suffix'] = options.suffix.split(',')
-        if options.replace:
-            self.args['replace'] = options.replace.split(',')
-
-    def _get_affix(self, affix_type, running_test):
+    @staticmethod
+    def _get_affix(keywords, running_test):
         """
         Returns list containing affixes that will be appended to docstring.
-        :param affix_type: 'suffix' or 'prefix'
-        :type affix_type: str
+
+        :param keywords: list of affix keywords
+        :type keywords: list
         :param running_test: contains meta information about the current test
         :return: a list containing wanted affixes depending on 'affix_type'
         """
-        affix = list()
-
-        if not affix_type in self.args.keys():
+        if not keywords:
             return ''
 
-        for key in self.args[affix_type]:
-            affix.append(running_test.keywords.get(key, ''))
+        keywords = keywords.split(',')
 
-        # remove empty strings resulted from unexisting keys
-        affix = filter(len, map(str, affix))
-
-        return ', '.join(affix)
+        affix = [str(running_test.keywords.get(key, '')) for key in keywords]
+        return '(' + ', '.join(filter(len, affix)) + ')'
 
     def _get_docstring(self, running_test):
         """
         Returns modified docstring if --replace is toggled, original otherwise.
+
         :return: modified docstring
         """
         docstring = running_test.__doc__
-        if 'replace' in self.args.keys() and len(self.args['replace']) == 2:
-            return docstring.replace(self.args['replace'][0],
-                                     self.args['replace'][1])
+        replace_args = (self.conf.options.replace or '').split(',')
+
+        if len(replace_args) == 2:
+            return docstring.replace(replace_args[0], replace_args[1])
+
         return docstring
\ No newline at end of file
